function chart_invoice (widget) {
    "use strict";

    var model = openerp;

    widget.ChartInvoiceWidget = widget.Base.extend({
        template: 'ChartInvoice',
        data: [],

        events: {
            'click .week': 'showWeeks',
            'click .days': 'showDays',
            'click .month': 'showMonths',
        },

        init: function (parent) {
            this._super(parent, {
                width: 6,
                height: 4
            });
        },
        start: function () {
            var self = this;
            self.fetchInitial();
        },
        fetchInitial:function() {
            var self = this;
            self.$el.block({
                message: null,
                overlayCSS: {
                    backgroundColor: '#FAFAFA'
                }
            });

            self.$el.find('.widget-content.widget-loading').css('display','flex');

            self.fecthAccountInvoice().then(function (AccountInvoice) {
                return AccountInvoice;
            }).then(function (AccountInvoice) {
                self.AccountInvoice = AccountInvoice;
                return self.showMonths();
            });
        },
  
        // Obtener facturas
        fecthAccountInvoice: function() {
            var self = this;
            var defer = $.Deferred();
            var fields = ['id','date_invoice','partner_id','amount_total','number','type'];
            var domain = [['state','in',['paid','open']]];
            var AccountInvoice = new model.web.Model('account.invoice');
            AccountInvoice.query(fields).filter(domain).all().then(function (results) {
                defer.resolve(results);
            });
            return defer;
        },

        // Obtener facturas deproveedores por mes
        getInAccountInvoice:function(mes) {
            var self = this;
            if (mes < 10){
                var fecha = moment().format('YYYY')+'-'+'0'+mes;    
            }else{
                var fecha = moment().format('YYYY')+'-'+mes;    
            }
            return _.flatten(_.filter(self.AccountInvoice,function (inv) {
                return moment(inv.date_invoice).format('YYYY-MM') === fecha & inv.type === 'in_invoice';
            }));
        },

        // Obtener facturas de clientes por mes
        getOutAccountInvoice:function(mes) {
            var self = this;
            if (mes < 10){
                var fecha = moment().format('YYYY')+'-'+'0'+mes;    
            }else{
                var fecha = moment().format('YYYY')+'-'+mes;    
            }
            return _.flatten(_.filter(self.AccountInvoice,function (inv) {
                return moment(inv.date_invoice).format('YYYY-MM') === fecha & inv.type === 'out_invoice';
            }));
        },

        // Facturas de Proveedores por dias
        getInDaysAccountInvoice:function(day) {
            var self = this;
            var date = moment().subtract(day, 'days').format('YYYY-MM-DD');
            return _.flatten(_.filter(self.AccountInvoice,function (inv) {
                return moment(inv.date_invoice).format('YYYY-MM-DD') === date & inv.type === 'in_invoice';
            }));
        },

        // Facturas de Clientes por dias
        getOutDaysAccountInvoice:function(day) {
            var self = this;
            var date = moment().subtract(day, 'days').format('YYYY-MM-DD');
            return _.flatten(_.filter(self.AccountInvoice,function (inv) {
                return moment(inv.date_invoice).format('YYYY-MM-DD') === date & inv.type === 'out_invoice';
            }));
        },

        // Facturas de proveedor semana actual
        getInWeekAccountInvoice:function(day) {
            var self = this;
            var week = moment().week();
            return _.flatten(_.filter(self.AccountInvoice,function (inv) {
                return moment(inv.date_invoice).week() === week & moment(inv.date_invoice).isoWeekday() === day & inv.type === 'in_invoice';
            }));
        },

        // Facturas de clientes semana Actual
        getOutWeekAccountInvoice:function(day) {
            var self = this;
            var week = moment().week();
            return _.flatten(_.filter(self.AccountInvoice,function (inv) {
                return moment(inv.date_invoice).week() === week & moment(inv.date_invoice).isoWeekday() === day & inv.type === 'out_invoice';
            }));
        },

        // Mostrar grafico por dias
        showDays: function() {
            var self = this;
            var title = [];
            var invoices;
            var dataIn = [];
            var dataOut = [];
            for (var i = 15; i >= 0; i--) {
                invoices = self.getInDaysAccountInvoice(i);
                var total = _.reduce(_.map(invoices,function(item) {
                    return item.amount_total;
                }),function(memo, num) {
                    return memo + num;
                },0);
                dataIn.push(total);
                title.push(moment().subtract(i, 'days').format('DD / MM'));
            }
            
            for (var i = 15; i >= 0; i--) {
                invoices = self.getOutDaysAccountInvoice(i);
                var total = _.reduce(_.map(invoices,function(item) {
                    return item.amount_total;
                }),function(memo, num) {
                    return memo + num;
                },0);
                dataOut.push(total);
            }
            self.$el.unblock();
            self.$el.find('.widget-content.widget-loading').css('display','none');
            self.fetchChart(dataIn, dataOut, title);
        },

        // Mostrar por meses
        showMonths: function() {
            var self = this;
            var title = ['Enero', 'Febrero', 'Marzo','Abril','Mayo','Junio','Julio','Agosto','Septiembre','Octubre','Noviembre','Diciembre'];
            var invoices;
            var mes = 0;
            var dataIn = [];
            var dataOut = [];
            for (var i = 1; i <= 12; i++) {
                invoices = self.getInAccountInvoice(i);
                var total = _.reduce(_.map(invoices,function(item) {
                    return item.amount_total;
                }),function(memo, num) {
                    return memo + num;
                },0);
                dataIn.push(total);
            }
            for (var i = 1; i <= 12; i++) {
                invoices = self.getOutAccountInvoice(i);
                var total = _.reduce(_.map(invoices,function(item) {
                    return item.amount_total;
                }),function(memo, num) {
                    return memo + num;
                },0);
                dataOut.push(total);
            }
            self.$el.unblock();
            self.$el.find('.widget-content.widget-loading').css('display','none');
            self.fetchChart(dataIn, dataOut, title);
        },

        // Mostrar por semana Actual
        showWeeks: function() {
            var self = this;
            var title = ['Lunes', 'Martes', 'Miercoles','Jueves','Viernes','Sabado','Domingo'];
            var invoices;
            var mes = 0;
            var dataIn = [];
            var dataOut = [];
            for (var i = 1; i <= 7; i++) {
                invoices = self.getInWeekAccountInvoice(i);
                var total = _.reduce(_.map(invoices,function(item) {
                    return item.amount_total;
                }),function(memo, num) {
                    return memo + num;
                },0);
                dataIn.push(total);
            }
            for (var i = 1; i <= 7; i++) {
                invoices = self.getOutWeekAccountInvoice(i);
                var total = _.reduce(_.map(invoices,function(item) {
                    return item.amount_total;
                }),function(memo, num) {
                    return memo + num;
                },0);
                dataOut.push(total);
            }
            self.$el.unblock();
            self.$el.find('.widget-content.widget-loading').css('display','none');
            self.fetchChart(dataIn, dataOut, title);
        },

        // Generar Grafico
        fetchChart: function (dataIn,dataOut,title) {
            var self = this;
            var label = title;
            var bodyIn = dataIn;
            var bodyOut = dataOut;
            var item;

            // Global method for setting Y axis number format.
            Chart.scaleService.updateScaleDefaults('linear', {
              ticks: {
                callback: function(tick) {
                    return tick.toLocaleString('de-DE');
                }
              }
            });
            Chart.defaults.global.tooltips.callbacks.label = function(tooltipItem, data) {
                var dataset = data.datasets[tooltipItem.datasetIndex];
                var datasetLabel = dataset.label || '';
                return datasetLabel +  dataset.data[tooltipItem.index].toLocaleString('de-DE');
            };
            var chart = new Chart(this.$el.find(".widget-content").find('canvas'), {
                type: 'line',
                data: {
                    labels: label,
                    datasets: [
                        {
                            label: 'Clientes  ',
                            data: bodyOut,
                            backgroundColor: '#e3f2fd',
                            borderColor: '#64b5f6',
                            borderWidth: 2,
                            fill: false,
                        },
                        {
                            label: 'Proveedores  ',                            
                            data: bodyIn,
                            backgroundColor: '#c8e6c9',
                            borderColor: '#66bb6a',
                            borderWidth: 2,
                            fill: false,
                        }
                    ]
                },
                options: {
                    responsive: true,
                    title: {
                        display: true,
                    },
                    hover: {
                        mode: 'nearest',
                        intersect: true
                    },
                    layout: {
                        padding: {
                            top: 5,
                            bottom: 15,
                            left : 0,
                            rigth: 0,
                        }
                    },
                }
            });
        },
    });
}
