function chart_pos_order_customer (widget) {
    "use strict";

    var model = openerp;

    widget.ChartPosOrderCustomerWidget = widget.Base.extend({
        template: 'ChartPosOrderCustomer',
        data: [],

        events: {
            
        },
        init: function (parent) {
            this._super(parent, {
                width: 6,
                height: 4
            });
        },
        start: function () {
            var self = this;
            self.fetchInitial();
        },
        fetchInitial:function() {
            var self = this;
            self.$el.block({
                message: null,
                overlayCSS: {
                    backgroundColor: '#FAFAFA'
                }
            });

            self.$el.find('.widget-content.widget-loading').css('display','flex');

            self.fecthPosOrder().then(function (PosOrder) {
                return PosOrder;
            }).then(function (PosOrder) {
                self.PosOrder = PosOrder;
                return self.fecthPartner(PosOrder);
            }).then(function (resPartner) {
                self.resPartner = resPartner;
                return self.fetchProductRanking();
            });
        },

        // Obtener Pedidos
        fecthPosOrder: function() {
            var self = this;
            var desde = moment().format('YYYY-MM-01 00:00:00');
            var hasta = moment().add(1,'months').format('YYYY-MM-01 00:00:00');
            var defer = $.Deferred();
            var fields = ['id','date_order','partner_id','amount_total'];
            var domain = [['state', 'in', ['paid','done','invoiced']], ['partner_id', '!=', false], ['date_order', '>=', desde], ['date_order', '<', hasta]];
            var PosOrder = new model.web.Model('pos.order');
            PosOrder.query(fields).filter(domain).all().then(function (results) {
                defer.resolve(results);
            });

            return defer;
        },
        // Consultar Clientes
        fecthPartner: function(PosOrder) {
            var self = this;
            var defer = $.Deferred();
            var partner_id = _.map(PosOrder,function(map){
                return map.partner_id[0];
            });
            var fields = ['id', 'name'];
            var domain = [['id', 'in', partner_id],['active', '=', true],['customer','=',true]];
            var resPartner = new model.web.Model('res.partner');
            resPartner.query(fields).filter(domain).all().then(function(results) {
                defer.resolve(results);
            });

            return defer;
        },
        // Obtener facturas por cada clientes
        getPosOrder:function(partner_id) {
            var self = this;
            return _.flatten(_.filter(self.PosOrder,function (inv) {
                return inv.partner_id[0] === partner_id;
            }));
        },
        // Generar el Ranking
        fetchProductRanking: function() {
            var self = this;
            var itemPartner;
            var itemPosOrder;
            var countPosOrder = 0
            var ranking = [];

            for (var i = 0; i < self.resPartner.length; i++) {
                itemPartner = self.resPartner[i];
                itemPosOrder = self.getPosOrder(itemPartner.id);

                var quantity = _.reduce(_.map(itemPosOrder,function(item) {
                    return item.amount_total;
                }),function(memo, num) {
                    return memo + num;
                },0);

                ranking.push({
                    id: itemPartner.id,
                    name: itemPartner.name,
                    countPosOrder: quantity
                });
            }
            ranking.sort(function (a, b) {
                return b.countPosOrder - a.countPosOrder
            });
            self.ranking = ranking;

            self.$el.unblock();
            self.$el.find('.widget-content.widget-loading').css('display','none');
            self.fetchChart(ranking);
        },

        // Generar Grafico
        fetchChart: function (ranking) {
            var self = this;
            var label = [];
            var body = [];
            var item;
            var rank = 7;
            if (ranking.length < rank && ranking.length > 0 ){
                rank= ranking.length;
            }
            for (var i = 0; i < rank; i++) {
                if (ranking[i]) {
                    item = ranking[i];
                }
                if (ranking.length === 0) {
                    item = {};
                    item.name = "N/A";
                    item.countPosOrder = 0;
                }
                label.push(item.name);
                body.push(item.countPosOrder);
            }
            Chart.scaleService.updateScaleDefaults('linear', {
              ticks: {
                callback: function(tick) {
                    return tick.toLocaleString('de-DE');
                }
              }
            });
            Chart.defaults.global.tooltips.callbacks.label = function(tooltipItem, data) {
                var dataset = data.datasets[tooltipItem.datasetIndex];
                var datasetLabel = dataset.label || '';
                return datasetLabel +  dataset.data[tooltipItem.index].toLocaleString('de-DE');
            };
            var chart = new Chart(this.$el.find(".widget-content").find('canvas'), {
                type: 'line',
                data: {
                    labels: label,
                    datasets: [
                        {
                            label: 'Ranking  ',
                            backgroundColor: '#e3f2fd',
                            borderColor: '#64b5f6',
                            borderWidth: 2,
                            data: body,
                            fill: false,
                        }
                    ]
                },
                options: {
                    responsive: true,
                    title: {
                        display: false,
                    },
                    hover: {
                        mode: 'nearest',
                        intersect: true
                    },
                    legend: {
                       display: false,
                    },
                    layout: {
                        padding: {
                            top: 40,
                            bottom: 10,
                            left : 0,
                            rigth: 0,
                        }
                    },
                }
            });
        },
    });
}
